@@ -15,7 +15,7 @@ use strict;
 use vars qw($VERSION);
 use Image::ExifTool qw(:DataAccess :Utils);
 
-$VERSION = '1.01';
+$VERSION = '1.03';
 
 # APE metadata blocks
 %Image::ExifTool::APE::Main = (
@@ -23,7 +23,8 @@ $VERSION = '1.01';
     NOTES => q{
         Tags found in Monkey's Audio (APE) information.  Only a few common tags are
         listed below, but ExifTool will extract any tag found.  ExifTool supports
-        APEv1 and APEv2 tags, as well as ID3 information in APE files.
+        APEv1 and APEv2 tags, as well as ID3 information in APE files, and will also
+        read APE metadata from MP3 and MPC files.
     },
     Album   => { },
     Artist  => { },
@@ -92,23 +93,25 @@ sub MakeTag($$)
 # Returns: 1 on success, 0 if this wasn't a valid APE file
 sub ProcessAPE($$)
 {
-    my ($exifTool, $dirInfo) = @_;
+    my ($et, $dirInfo) = @_;
 
     # must first check for leading/trailing ID3 information
-    unless ($exifTool->{DoneID3}) {
+    unless ($$et{DoneID3}) {
         require Image::ExifTool::ID3;
-        Image::ExifTool::ID3::ProcessID3($exifTool, $dirInfo) and return 1;
+        Image::ExifTool::ID3::ProcessID3($et, $dirInfo) and return 1;
     }
     my $raf = $$dirInfo{RAF};
-    my $verbose = $exifTool->Options('Verbose');
-    my ($buff, $i, $header, $tagTablePtr, $dataPos);
+    my $verbose = $et->Options('Verbose');
+    my ($buff, $i, $header, $tagTablePtr, $dataPos, $oldIndent);
+
+    $$et{DoneAPE} = 1;
 
     # check APE signature and process audio information
     # unless this is some other type of file
-    unless ($exifTool->{VALUE}->{FileType}) {
+    unless ($$et{VALUE}{FileType}) {
         $raf->Read($buff, 32) == 32 or return 0;
         $buff =~ /^(MAC |APETAGEX)/ or return 0;
-        $exifTool->SetFileType();
+        $et->SetFileType();
         SetByteOrder('II');
 
         if ($buff =~ /^APETAGEX/) {
@@ -130,7 +133,7 @@ sub ProcessAPE($$)
                     }
                 }
             }
-            $exifTool->ProcessDirectory( { DataPt => \$buff }, $table) if $table;
+            $et->ProcessDirectory( { DataPt => \$buff }, $table) if $table;
         }
     }
     # look for APE trailer unless we already found an APE header
@@ -138,7 +141,7 @@ sub ProcessAPE($$)
         # look for the APE trailer footer...
         my $footPos = -32;
         # (...but before the ID3v1 trailer if it exists)
-        $footPos -= 128 if $exifTool->{DoneID3} == 2;
+        $footPos -= 128 if $$et{DoneID3} == 2;
         $raf->Seek($footPos, 2)     or return 1;
         $raf->Read($buff, 32) == 32 or return 1;
         $buff =~ /^APETAGEX/        or return 1;
@@ -155,8 +158,10 @@ sub ProcessAPE($$)
         $raf->Read($buff, $size) == $size)
     {
         if ($verbose) {
-            $exifTool->VerboseDir("APEv$version", $count, $size);
-            $exifTool->VerboseDump(\$buff, DataPos => $raf->Tell() - $size);
+            $oldIndent = $$et{INDENT};
+            $$et{INDENT} .= '| ';
+            $et->VerboseDir("APEv$version", $count, $size);
+            $et->VerboseDump(\$buff, DataPos => $raf->Tell() - $size);
         }
         $tagTablePtr = GetTagTable('Image::ExifTool::APE::Main');
         $dataPos = $raf->Tell() - $size;
@@ -175,6 +180,8 @@ sub ProcessAPE($$)
         pos($buff) = $pos + 8;
         last unless $buff =~ /\G(.*?)\0/sg;
         my $tag = $1;
+        # avoid conflicts with our special table entries
+        $tag .= '.' if $Image::ExifTool::specialTags{$tag};
         $pos = pos($buff);
         last if $pos + $len > $size;
         my $val = substr($buff, $pos, $len);
@@ -190,11 +197,11 @@ sub ProcessAPE($$)
                     my $t = "$tag Desc";
                     my $v = $1;
                     MakeTag($t, $tagTablePtr) unless $$tagTablePtr{$t};
-                    $exifTool->HandleTag($tagTablePtr, $t, $v);
+                    $et->HandleTag($tagTablePtr, $t, $v);
                 }
             }
         }
-        $exifTool->HandleTag($tagTablePtr, $tag, $val,
+        $et->HandleTag($tagTablePtr, $tag, $val,
             Index => $i,
             DataPt => \$buff,
             DataPos => $dataPos,
@@ -203,7 +210,8 @@ sub ProcessAPE($$)
         );
         $pos += $len;
     }
-    $i == $count or $exifTool->Warn('Bad APE trailer');
+    $i == $count or $et->Warn('Bad APE trailer');
+    $$et{INDENT} = $oldIndent if defined $oldIndent;
     return 1;
 }
 
@@ -230,7 +238,7 @@ Currently doesn't parse MAC header unless it is at the start of the file.
 
 =head1 AUTHOR
 
-Copyright 2003-2012, Phil Harvey (phil at owl.phy.queensu.ca)
+Copyright 2003-2014, Phil Harvey (phil at owl.phy.queensu.ca)
 
 This library is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
