@@ -23,7 +23,7 @@ use vars qw($VERSION);
 use Image::ExifTool qw(:DataAccess :Utils);
 use Image::ExifTool::Exif;
 
-$VERSION = '1.10';
+$VERSION = '1.11';
 
 sub ProcessFLIR($$;$);
 sub ProcessFLIRText($$$);
@@ -1310,7 +1310,7 @@ sub ProcessMeasInfo($$$)
         my $pre = 'Meas' . $i;
         $et->VerboseDir("MeasInfo $i", undef, $recLen);
         if ($verbose > 2) {
-            Image::ExifTool::HexDump($dataPt, $recLen,
+            HexDump($dataPt, $recLen,
                 Start=>$pos, Prefix=>$$et{INDENT}, DataPos=>$dataPos);
         }
         my $coordLen = Get16u($dataPt, $pos+4);
@@ -1382,10 +1382,11 @@ sub ProcessFLIR($$;$)
 
     # determine byte ordering by validating version number
     # (in my samples FLIR APP1 is big-endian, FFF files are little-endian)
-    my $ver = Get32u(\$hdr, 0x14);
-    if ($ver != 100) {
-        $ver == 0x64000000 or $et->Warn("Unsupported FLIR $type version"), return 1;
+    for ($i=0; ; ++$i) {
+        my $ver = Get32u(\$hdr, 0x14);
+        last if $ver >= 100 and $ver < 200; # (have seen 100 and 101 - PH)
         ToggleByteOrder();
+        $i and $et->Warn("Unsupported FLIR $type version"), return 1;
     }
 
     # read the FLIR record directory
@@ -1445,7 +1446,7 @@ sub ProcessFLIR($$;$)
         } elsif ($verbose > 2) {
             my %parms = ( DataPos => $recPos, Prefix => $$et{INDENT} );
             $parms{MaxLen} = 96 if $verbose < 4;
-            Image::ExifTool::HexDump(\$rec, $recLen, %parms);
+            HexDump(\$rec, $recLen, %parms);
         }
     }
     delete $$et{SET_GROUP0};
