@@ -4,8 +4,9 @@
 # Description:  Read GeoTiff meta information
 #
 # Revisions:    02/23/2004 - P. Harvey Created
-#               02/25/2004 - P. Harvey Added new codes from libgeotiff-1.2.1
-#               02/01/2007 - P. Harvey Added new codes from libgeotiff-1.2.3
+#               02/25/2004 - PH Added new codes from libgeotiff-1.2.1
+#               02/01/2007 - PH Added new codes from libgeotiff-1.2.3
+#               01/22/2014 - PH Added new code from libgeotiff-1.4.0
 #
 # Reference:    ftp://ftp.remotesensing.org/geotiff/libgeotiff/libgeotiff-1.1.4.tar.gz
 #------------------------------------------------------------------------------
@@ -16,7 +17,7 @@ use strict;
 use vars qw($VERSION);
 use Image::ExifTool qw(:DataAccess :Utils);
 
-$VERSION = '1.07';
+$VERSION = '1.10';
 
 # format codes for geoTiff directory entries
 my %geoTiffFormat = (
@@ -504,6 +505,7 @@ my %epsg_units = (
         PrintConv => \%epsg_units,
     },
     2061 => 'GeogPrimeMeridianLong',
+    2062 => 'GeogToWGS84',
     3072 => {
         Name => 'ProjectedCSType',
         PrintConv => {
@@ -2068,13 +2070,17 @@ my %epsg_units = (
 # Notes: byte order must be set before calling this routine
 sub ProcessGeoTiff($)
 {
-    my $exifTool = shift;
-    my $dirData = $exifTool->GetValue('GeoTiffDirectory', 'ValueConv') or return;
-    my $doubleData = $exifTool->GetValue('GeoTiffDoubleParams', 'ValueConv');
-    my $asciiData = $exifTool->GetValue('GeoTiffAsciiParams', 'ValueConv');
-    my $verbose = $exifTool->Options('Verbose');
+    my $et = shift;
+    my $dirData = $et->GetValue('GeoTiffDirectory', 'ValueConv') or return;
+
+    # avoid re-processing if another EXIF directory is found
+    $$et{DidGeoTiff} and $$et{DidGeoTiff} eq $dirData and return;
+    $$et{DidGeoTiff} = $dirData;
+
+    my $doubleData = $et->GetValue('GeoTiffDoubleParams', 'ValueConv');
+    my $asciiData = $et->GetValue('GeoTiffAsciiParams', 'ValueConv');
+    my $verbose = $et->Options('Verbose');
 
-    # restore or original EXIF byte order setting
     if (length($$dirData) >= 8 and
         length($$dirData) >= 8 * (Get16u($dirData,6) + 1))
     {
@@ -2084,30 +2090,38 @@ sub ProcessGeoTiff($)
         my $numEntries = Get16u($dirData,6);
 
         if ($verbose) {
-            $exifTool->{INDENT} .= '| ';
-            $exifTool->VerboseDir('GeoTiff',$numEntries);
+            $$et{INDENT} .= '| ';
+            $et->VerboseDir('GeoTiff',$numEntries);
         }
         # generate version number tag (not a real GeoTiff tag)
         my $tagTable = GetTagTable("Image::ExifTool::GeoTiff::Main");
-        my $tagInfo = $exifTool->GetTagInfo($tagTable, 1);
-        $tagInfo and $exifTool->FoundTag($tagInfo,"$version.$revision.$minorRev");
+        my $tagInfo = $et->GetTagInfo($tagTable, 1);
+        $tagInfo and $et->FoundTag($tagInfo,"$version.$revision.$minorRev");
 
         my $i;
         for ($i=0; $i<$numEntries; ++$i) {
             my $pt = 8 * ($i + 1);
             my $tag    = Get16u($dirData, $pt);
-            $tagInfo   = $exifTool->GetTagInfo($tagTable, $tag) or next;
+            $tagInfo   = $et->GetTagInfo($tagTable, $tag) or next;
             my $loc    = Get16u($dirData, $pt+2);
             my $count  = Get16u($dirData, $pt+4);
             my $offset = Get16u($dirData, $pt+6);
             my $format = $geoTiffFormat{$loc};
             my ($val, $dataPt);
             if ($format eq 'double') {          # in the double parms
+                if (not $doubleData or length($$doubleData) < 8*($offset+$count)) {
+                    $et->Warn("Missing double data for $$tagInfo{Name}");
+                    next;
+                }
                 $dataPt = $doubleData;
                 $offset *= 8;
                 $val = Image::ExifTool::ReadValue($dataPt, $offset, $format,
                                                   $count, length($$doubleData)-$offset);
             } elsif ($format eq 'string') {     # in the ASCII parms
+                if (not $asciiData or length($$asciiData) < $offset+$count) {
+                    $et->Warn("Missing string data for $$tagInfo{Name}");
+                    next;
+                }
                 $dataPt = $asciiData;
                 $val = substr($$dataPt, $offset, $count);
                 $val =~ s/(\0|\|)$//;   # remove trailing terminator (NULL or '|')
@@ -2116,10 +2130,10 @@ sub ProcessGeoTiff($)
                 $val = $offset;
                 $offset = $pt+6;
             } else {
-                $exifTool->Warn("Unknown GeoTiff location: $loc");
+                $et->Warn("Unknown GeoTiff location: $loc");
                 next;
             }
-            $verbose and $exifTool->VerboseInfo($tag, $tagInfo,
+            $verbose and $et->VerboseInfo($tag, $tagInfo,
                 'Table'  => $tagTable,
                 'Index'  => $i,
                 'Value'  => $val,
@@ -2129,19 +2143,20 @@ sub ProcessGeoTiff($)
                 'Count'  => $count,
                 'Size'   => $count * Image::ExifTool::FormatSize($format),
             );
-            $exifTool->FoundTag($tagInfo, $val);
+            $et->FoundTag($tagInfo, $val);
         }
         if ($verbose) {
-            $exifTool->{INDENT} =~ s/..$//;
+            $$et{INDENT} =~ s/..$//;
         }
     } else {
-        $exifTool->Warn('Bad GeoTIFF directory');
+        $et->Warn('Bad GeoTIFF directory');
+    }
+    # extract block tags only if requested
+    unless ($$et{OPTIONS}{RequestAll}) {
+        $et->DeleteTag('GeoTiffDirectory')    unless $$et{REQ_TAG_LOOKUP}{geotiffdirectory};
+        $et->DeleteTag('GeoTiffDoubleParams') unless $$et{REQ_TAG_LOOKUP}{geotiffdoubleparams};
+        $et->DeleteTag('GeoTiffAsciiParams')  unless $$et{REQ_TAG_LOOKUP}{geotiffasciiparams};
     }
-    # must delete these tags once we've processed this information
-    # (to avoid re-processing if another EXIF directory is found)
-    $exifTool->DeleteTag('GeoTiffDirectory');
-    $exifTool->DeleteTag('GeoTiffDoubleParams');
-    $exifTool->DeleteTag('GeoTiffAsciiParams');
 }
 
 
@@ -2166,7 +2181,7 @@ coordinates.
 
 =head1 AUTHOR
 
-Copyright 2003-2013, Phil Harvey (phil at owl.phy.queensu.ca)
+Copyright 2003-2014, Phil Harvey (phil at owl.phy.queensu.ca)
 
 This library is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
